@@ -10,9 +10,9 @@ def find_unused_port():
 
 
 def command(settings):
-    import webbrowser
     import threading
     import time
+    import webbrowser
 
     try:
         import sr.comp.scorer  # type: ignore[import]
@@ -27,7 +27,7 @@ def command(settings):
 
     def browse():
         time.sleep(1.5)
-        webbrowser.open('http://localhost:{}/'.format(port))
+        webbrowser.open(f'http://localhost:{port}/')
 
     thread = threading.Thread(target=browse)
     thread.start()
